>From 96cf0f5637b9df5c306794a148b8da77391c3777 Mon Sep 17 00:00:00 2001
From: Joseph Tulou <brezhoneg1@yahoo.fr>
Date: Sat, 10 Jan 2009 21:04:01 +0100
Subject: [PATCH] additional syntaxes for still images

   vlc image.ext
   vlc fake://image.ext
are made equivalent to existing :
   vlc fake:// --fake-file=image.ext
---
 modules/access/fake.c |   29 ++++++++++++++++++++++++++---
 1 files changed, 26 insertions(+), 3 deletions(-)

diff --git a/modules/access/fake.c b/modules/access/fake.c
index 2e0d990..75dbed0 100644
--- a/modules/access/fake.c
+++ b/modules/access/fake.c
@@ -33,6 +33,8 @@
 #include <vlc_plugin.h>
 #include <vlc_access.h>
 #include <vlc_demux.h>
+#include <vlc_image.h>
+#include <assert.h>
 
 /*****************************************************************************
  * Module descriptior
@@ -70,7 +72,7 @@ vlc_module_begin ()
                  true );
 
     add_shortcut( "fake" )
-    set_capability( "access_demux", 0 )
+    set_capability( "access_demux", 10 )
     set_callbacks( Open, Close )
 vlc_module_end ()
 
@@ -97,10 +99,31 @@ static int Open( vlc_object_t *p_this )
     demux_sys_t *p_sys;
     es_format_t fmt;
 
-    /* Only when selected */
-    if( *p_demux->psz_access == '\0' )
+    /* if access is provided, it is expected to be "fake" */
+    if( *p_demux->psz_access != '\0' && strcmp( p_demux->psz_access, "fake" ) )
         return VLC_EGENERIC;
 
+   /**
+    * if path is provided, let's see if it could be an image
+    *   "vlc fake://image.ext" or "vlc image.ext" are made
+    *   equivalent to a "vlc fake:// :fake-file=image.ext"
+    *
+    **/
+    if( p_demux->psz_path && *p_demux->psz_path )
+    {
+        vlc_fourcc_t i_codec = image_Ext2Fourcc( p_demux->psz_path );
+        if( !i_codec )
+            return VLC_EGENERIC;
+    
+        msg_Dbg( p_demux, "still image detected with %4.4s format",
+                          (const char*) &i_codec );
+
+        /* set up fake-file on the fly (attached to the input object) */
+        assert( p_demux->p_parent );
+        var_Create( p_demux->p_parent, "fake-file", VLC_VAR_STRING );
+        var_SetString( p_demux->p_parent, "fake-file", p_demux->psz_path );
+    }
+    
     /* Set up p_demux */
     DEMUX_INIT_COMMON(); p_sys = p_demux->p_sys;
     p_demux->info.i_update = 0;
-- 
1.5.2.5

